@@ -74,7 +74,7 @@ if os.path.exists('/proc/version'):
 if ubuntu:
 	ubuntu_vers = open('/etc/lsb-release').readlines()[1].split('=')[1].replace('\n','')
 # Debian
-debian = os.path.exists('/etc/debian_version')
+debian = os.path.exists('/etc/debian_version') and not ubuntu
 debian_vers = None
 if debian:
 	debian_vers = open('/etc/debian_version').read().replace('\n','')
@@ -85,9 +85,9 @@ archlinux_vers = None
 centos = 'centos' in platform.dist()[0].lower()
 centos_vers = None
 if centos_vers:
-	centos_vers = platform.dist()[1].split('.')[0]
+	centos_vers = platform.dist()[1]
 # Redhat
 redhat = 'redhat' in platform.dist()[0].lower()
 redhat_vers = None
 if redhat:
-	redhat_vers = platform.dist()[1].split('.')[0]
+	redhat_vers = platform.dist()[1]
